**Example 1: 终止同步任务**



Input: 

```
tccli dts StopSyncJob --cli-unfold-argument  \
    --JobId sync-7r1cz016
```

Output: 
```
{
    "Response": {
        "RequestId": "ead9fdc1-baa8-4a09-aaa1-c2012690c976"
    }
}
```

